==> starfile-0.3.0-py3-none-any.whl: starfile/functions.py <==
from typing import Union, List

import pandas as pd

from .starfile import StarFile
from .version import __version__


def open(filename: str, max_data_blocks: int = None) -> Union[pd.DataFrame, List[pd.DataFrame]]:
    """
    Read a star file into a pandas dataframe or list of pandas dataframes
    :param filename: file from which to read dataframes
    :return:
    """
    df = StarFile(filename).data
    return df


def read(filename: str, max_data_blocks: int = None) -> Union[pd.DataFrame, List[pd.DataFrame]]:
    """
    Read a star file into a pandas dataframe or list of pandas dataframes
    :param filename: file from which to read dataframes
    :return:
    """
    df = open(filename, max_data_blocks)
    return df


def new(data: Union[pd.DataFrame, List[pd.DataFrame]], filename: str, **kwargs):
    """
    Write dataframes from pandas dataframe(s) to a star file
    :param data: dataframes in pandas dataframe(s) to be written to file
    :param filename: filename in which to new dataframes
    :return:
    """
    star = StarFile(data=data)
    star.write_star_file(filename, **kwargs)
    return


def write(data: Union[pd.DataFrame, List[pd.DataFrame]], filename: str):
    """
    Write dataframes from pandas dataframe(s) to a star file
    :param data: dataframes in pandas dataframe(s) to be written to file
    :param filename: filename in which to new dataframes
    :return:
    """
    star = StarFile(data=data)
    star.write_star_file(filename)
    return


def star2excel(star_file: str, excel_filename: str):
    """
    Converts a star file to an excel (.xlsx) file
    :param star_file: STAR file
    :param excel_filename: filename (should end in '.xlsx')
    :return:
    """
    star = StarFile(star_file)
    star.to_excel(excel_filename)
    return


def version():
    """
    Returns the current version of starfile
    :return:
    """
    return __version__

==> starfile-0.3.3-py3-none-any.whl: starfile/functions.py <==
from typing import Union, List
from pathlib import Path

import pandas as pd

from .starfile import StarFile
from .version import __version__


def open(filename: str, n_data_blocks: int = None) -> Union[pd.DataFrame, List[pd.DataFrame]]:
    """
    Read a star file into a pandas dataframe or list of pandas dataframes
    :param filename: file from which to read dataframes
    :return:
    """
    if Path(filename).exists():
        return StarFile(filename, read_n_blocks=n_data_blocks).data
    else:
        raise FileNotFoundError


def read(filename: str, n_data_blocks: int = None) -> Union[pd.DataFrame, List[pd.DataFrame]]:
    """
    Read a star file into a pandas dataframe or list of pandas dataframes
    :param filename: file from which to read dataframes
    :return:
    """
    df = open(filename, n_data_blocks)
    return df


def new(data: Union[pd.DataFrame, List[pd.DataFrame]], filename: str, **kwargs):
    """
    Write dataframes from pandas dataframe(s) to a star file
    :param data: dataframes in pandas dataframe(s) to be written to file
    :param filename: filename in which to new dataframes
    :return:
    """
    star = StarFile(data=data)
    star.write_star_file(filename, **kwargs)
    return


def write(data: Union[pd.DataFrame, List[pd.DataFrame]], filename: str):
    """
    Write dataframes from pandas dataframe(s) to a star file
    :param data: dataframes in pandas dataframe(s) to be written to file
    :param filename: filename in which to new dataframes
    :return:
    """
    star = StarFile(data=data)
    star.write_star_file(filename)
    return


def star2excel(star_file: str, excel_filename: str):
    """
    Converts a star file to an excel (.xlsx) file
    :param star_file: STAR file
    :param excel_filename: filename (should end in '.xlsx')
    :return:
    """
    star = StarFile(star_file)
    star.to_excel(excel_filename)
    return


def version():
    """
    Returns the current version of starfile
    :return:
    """
    return __version__
